/*
 *  EPSG/POSC Projection Codes - GeoTIFF Rev 0.2
 */

/* C database for Geotiff include files.   */
/* the macro ValuePair() must be defined   */
/* by the enclosing include file           */

#ifdef INCLUDE_OLD_CODES
#include old_proj.inc
#endif /* OLD Codes */

/* New codes */

ValuePair(Proj_Stereo_70,19926)

/* old codes */

ValuePair(Proj_Alabama_CS27_East,	10101)
ValuePair(Proj_Alabama_CS27_West,	10102)
ValuePair(Proj_Alabama_CS83_East,	10131)
ValuePair(Proj_Alabama_CS83_West,	10132)
ValuePair(Proj_Arizona_Coordinate_System_east,	10201)
ValuePair(Proj_Arizona_Coordinate_System_Central,	10202)
ValuePair(Proj_Arizona_Coordinate_System_west,	10203)
ValuePair(Proj_Arizona_CS83_east,	10231)
ValuePair(Proj_Arizona_CS83_Central,	10232)
ValuePair(Proj_Arizona_CS83_west,	10233)
ValuePair(Proj_Arkansas_CS27_North,	10301)
ValuePair(Proj_Arkansas_CS27_South,	10302)
ValuePair(Proj_Arkansas_CS83_North,	10331)
ValuePair(Proj_Arkansas_CS83_South,	10332)
ValuePair(Proj_California_CS27_I,	10401)
ValuePair(Proj_California_CS27_II,	10402)
ValuePair(Proj_California_CS27_III,	10403)
ValuePair(Proj_California_CS27_IV,	10404)
ValuePair(Proj_California_CS27_V,	10405)
ValuePair(Proj_California_CS27_VI,	10406)
ValuePair(Proj_California_CS27_VII,	10407)
ValuePair(Proj_California_CS83_1,	10431)
ValuePair(Proj_California_CS83_2,	10432)
ValuePair(Proj_California_CS83_3,	10433)
ValuePair(Proj_California_CS83_4,	10434)
ValuePair(Proj_California_CS83_5,	10435)
ValuePair(Proj_California_CS83_6,	10436)
ValuePair(Proj_Colorado_CS27_North,	10501)
ValuePair(Proj_Colorado_CS27_Central,	10502)
ValuePair(Proj_Colorado_CS27_South,	10503)
ValuePair(Proj_Colorado_CS83_North,	10531)
ValuePair(Proj_Colorado_CS83_Central,	10532)
ValuePair(Proj_Colorado_CS83_South,	10533)
ValuePair(Proj_Connecticut_CS27,	10600)
ValuePair(Proj_Connecticut_CS83,	10630)
ValuePair(Proj_Delaware_CS27,	10700)
ValuePair(Proj_Delaware_CS83,	10730)
ValuePair(Proj_Florida_CS27_East,	10901)
ValuePair(Proj_Florida_CS27_West,	10902)
ValuePair(Proj_Florida_CS27_North,	10903)
ValuePair(Proj_Florida_CS83_East,	10931)
ValuePair(Proj_Florida_CS83_West,	10932)
ValuePair(Proj_Florida_CS83_North,	10933)
ValuePair(Proj_Georgia_CS27_East,	11001)
ValuePair(Proj_Georgia_CS27_West,	11002)
ValuePair(Proj_Georgia_CS83_East,	11031)
ValuePair(Proj_Georgia_CS83_West,	11032)
ValuePair(Proj_Idaho_CS27_East,	11101)
ValuePair(Proj_Idaho_CS27_Central,	11102)
ValuePair(Proj_Idaho_CS27_West,	11103)
ValuePair(Proj_Idaho_CS83_East,	11131)
ValuePair(Proj_Idaho_CS83_Central,	11132)
ValuePair(Proj_Idaho_CS83_West,	11133)
ValuePair(Proj_Illinois_CS27_East,	11201)
ValuePair(Proj_Illinois_CS27_West,	11202)
ValuePair(Proj_Illinois_CS83_East,	11231)
ValuePair(Proj_Illinois_CS83_West,	11232)
ValuePair(Proj_Indiana_CS27_East,	11301)
ValuePair(Proj_Indiana_CS27_West,	11302)
ValuePair(Proj_Indiana_CS83_East,	11331)
ValuePair(Proj_Indiana_CS83_West,	11332)
ValuePair(Proj_Iowa_CS27_North,	11401)
ValuePair(Proj_Iowa_CS27_South,	11402)
ValuePair(Proj_Iowa_CS83_North,	11431)
ValuePair(Proj_Iowa_CS83_South,	11432)
ValuePair(Proj_Kansas_CS27_North,	11501)
ValuePair(Proj_Kansas_CS27_South,	11502)
ValuePair(Proj_Kansas_CS83_North,	11531)
ValuePair(Proj_Kansas_CS83_South,	11532)
ValuePair(Proj_Kentucky_CS27_North,	11601)
ValuePair(Proj_Kentucky_CS27_South,	11602)
ValuePair(Proj_Kentucky_CS83_North,	15303)
ValuePair(Proj_Kentucky_CS83_South,	11632)
ValuePair(Proj_Louisiana_CS27_North,	11701)
ValuePair(Proj_Louisiana_CS27_South,	11702)
ValuePair(Proj_Louisiana_CS83_North,	11731)
ValuePair(Proj_Louisiana_CS83_South,	11732)
ValuePair(Proj_Maine_CS27_East,	11801)
ValuePair(Proj_Maine_CS27_West,	11802)
ValuePair(Proj_Maine_CS83_East,	11831)
ValuePair(Proj_Maine_CS83_West,	11832)
ValuePair(Proj_Maryland_CS27,	11900)
ValuePair(Proj_Maryland_CS83,	11930)
ValuePair(Proj_Massachusetts_CS27_Mainland,	12001)
ValuePair(Proj_Massachusetts_CS27_Island,	12002)
ValuePair(Proj_Massachusetts_CS83_Mainland,	12031)
ValuePair(Proj_Massachusetts_CS83_Island,	12032)
ValuePair(Proj_Michigan_State_Plane_East,	12101)
ValuePair(Proj_Michigan_State_Plane_Old_Central,	12102)
ValuePair(Proj_Michigan_State_Plane_West,	12103)
ValuePair(Proj_Michigan_CS27_North,	12111)
ValuePair(Proj_Michigan_CS27_Central,	12112)
ValuePair(Proj_Michigan_CS27_South,	12113)
ValuePair(Proj_Michigan_CS83_North,	12141)
ValuePair(Proj_Michigan_CS83_Central,	12142)
ValuePair(Proj_Michigan_CS83_South,	12143)
ValuePair(Proj_Minnesota_CS27_North,	12201)
ValuePair(Proj_Minnesota_CS27_Central,	12202)
ValuePair(Proj_Minnesota_CS27_South,	12203)
ValuePair(Proj_Minnesota_CS83_North,	12231)
ValuePair(Proj_Minnesota_CS83_Central,	12232)
ValuePair(Proj_Minnesota_CS83_South,	12233)
ValuePair(Proj_Mississippi_CS27_East,	12301)
ValuePair(Proj_Mississippi_CS27_West,	12302)
ValuePair(Proj_Mississippi_CS83_East,	12331)
ValuePair(Proj_Mississippi_CS83_West,	12332)
ValuePair(Proj_Missouri_CS27_East,	12401)
ValuePair(Proj_Missouri_CS27_Central,	12402)
ValuePair(Proj_Missouri_CS27_West,	12403)
ValuePair(Proj_Missouri_CS83_East,	12431)
ValuePair(Proj_Missouri_CS83_Central,	12432)
ValuePair(Proj_Missouri_CS83_West,	12433)
ValuePair(Proj_Montana_CS27_North,	12501)
ValuePair(Proj_Montana_CS27_Central,	12502)
ValuePair(Proj_Montana_CS27_South,	12503)
ValuePair(Proj_Montana_CS83,	12530)
ValuePair(Proj_Nebraska_CS27_North,	12601)
ValuePair(Proj_Nebraska_CS27_South,	12602)
ValuePair(Proj_Nebraska_CS83,	12630)
ValuePair(Proj_Nevada_CS27_East,	12701)
ValuePair(Proj_Nevada_CS27_Central,	12702)
ValuePair(Proj_Nevada_CS27_West,	12703)
ValuePair(Proj_Nevada_CS83_East,	12731)
ValuePair(Proj_Nevada_CS83_Central,	12732)
ValuePair(Proj_Nevada_CS83_West,	12733)
ValuePair(Proj_New_Hampshire_CS27,	12800)
ValuePair(Proj_New_Hampshire_CS83,	12830)
ValuePair(Proj_New_Jersey_CS27,	12900)
ValuePair(Proj_New_Jersey_CS83,	12930)
ValuePair(Proj_New_Mexico_CS27_East,	13001)
ValuePair(Proj_New_Mexico_CS27_Central,	13002)
ValuePair(Proj_New_Mexico_CS27_West,	13003)
ValuePair(Proj_New_Mexico_CS83_East,	13031)
ValuePair(Proj_New_Mexico_CS83_Central,	13032)
ValuePair(Proj_New_Mexico_CS83_West,	13033)
ValuePair(Proj_New_York_CS27_East,	13101)
ValuePair(Proj_New_York_CS27_Central,	13102)
ValuePair(Proj_New_York_CS27_West,	13103)
ValuePair(Proj_New_York_CS27_Long_Island,	13104)
ValuePair(Proj_New_York_CS83_East,	13131)
ValuePair(Proj_New_York_CS83_Central,	13132)
ValuePair(Proj_New_York_CS83_West,	13133)
ValuePair(Proj_New_York_CS83_Long_Island,	13134)
ValuePair(Proj_North_Carolina_CS27,	13200)
ValuePair(Proj_North_Carolina_CS83,	13230)
ValuePair(Proj_North_Dakota_CS27_North,	13301)
ValuePair(Proj_North_Dakota_CS27_South,	13302)
ValuePair(Proj_North_Dakota_CS83_North,	13331)
ValuePair(Proj_North_Dakota_CS83_South,	13332)
ValuePair(Proj_Ohio_CS27_North,	13401)
ValuePair(Proj_Ohio_CS27_South,	13402)
ValuePair(Proj_Ohio_CS83_North,	13431)
ValuePair(Proj_Ohio_CS83_South,	13432)
ValuePair(Proj_Oklahoma_CS27_North,	13501)
ValuePair(Proj_Oklahoma_CS27_South,	13502)
ValuePair(Proj_Oklahoma_CS83_North,	13531)
ValuePair(Proj_Oklahoma_CS83_South,	13532)
ValuePair(Proj_Oregon_CS27_North,	13601)
ValuePair(Proj_Oregon_CS27_South,	13602)
ValuePair(Proj_Oregon_CS83_North,	13631)
ValuePair(Proj_Oregon_CS83_South,	13632)
ValuePair(Proj_Pennsylvania_CS27_North,	13701)
ValuePair(Proj_Pennsylvania_CS27_South,	13702)
ValuePair(Proj_Pennsylvania_CS83_North,	13731)
ValuePair(Proj_Pennsylvania_CS83_South,	13732)
ValuePair(Proj_Rhode_Island_CS27,	13800)
ValuePair(Proj_Rhode_Island_CS83,	13830)
ValuePair(Proj_South_Carolina_CS27_North,	13901)
ValuePair(Proj_South_Carolina_CS27_South,	13902)
ValuePair(Proj_South_Carolina_CS83,	13930)
ValuePair(Proj_South_Dakota_CS27_North,	14001)
ValuePair(Proj_South_Dakota_CS27_South,	14002)
ValuePair(Proj_South_Dakota_CS83_North,	14031)
ValuePair(Proj_South_Dakota_CS83_South,	14032)
ValuePair(Proj_Tennessee_CS27,	15302)
ValuePair(Proj_Tennessee_CS83,	14130)
ValuePair(Proj_Texas_CS27_North,	14201)
ValuePair(Proj_Texas_CS27_North_Central,	14202)
ValuePair(Proj_Texas_CS27_Central,	14203)
ValuePair(Proj_Texas_CS27_South_Central,	14204)
ValuePair(Proj_Texas_CS27_South,	14205)
ValuePair(Proj_Texas_CS83_North,	14231)
ValuePair(Proj_Texas_CS83_North_Central,	14232)
ValuePair(Proj_Texas_CS83_Central,	14233)
ValuePair(Proj_Texas_CS83_South_Central,	14234)
ValuePair(Proj_Texas_CS83_South,	14235)
ValuePair(Proj_Utah_CS27_North,	14301)
ValuePair(Proj_Utah_CS27_Central,	14302)
ValuePair(Proj_Utah_CS27_South,	14303)
ValuePair(Proj_Utah_CS83_North,	14331)
ValuePair(Proj_Utah_CS83_Central,	14332)
ValuePair(Proj_Utah_CS83_South,	14333)
ValuePair(Proj_Vermont_CS27,	14400)
ValuePair(Proj_Vermont_CS83,	14430)
ValuePair(Proj_Virginia_CS27_North,	14501)
ValuePair(Proj_Virginia_CS27_South,	14502)
ValuePair(Proj_Virginia_CS83_North,	14531)
ValuePair(Proj_Virginia_CS83_South,	14532)
ValuePair(Proj_Washington_CS27_North,	14601)
ValuePair(Proj_Washington_CS27_South,	14602)
ValuePair(Proj_Washington_CS83_North,	14631)
ValuePair(Proj_Washington_CS83_South,	14632)
ValuePair(Proj_West_Virginia_CS27_North,	14701)
ValuePair(Proj_West_Virginia_CS27_South,	14702)
ValuePair(Proj_West_Virginia_CS83_North,	14731)
ValuePair(Proj_West_Virginia_CS83_South,	14732)
ValuePair(Proj_Wisconsin_CS27_North,	14801)
ValuePair(Proj_Wisconsin_CS27_Central,	14802)
ValuePair(Proj_Wisconsin_CS27_South,	14803)
ValuePair(Proj_Wisconsin_CS83_North,	14831)
ValuePair(Proj_Wisconsin_CS83_Central,	14832)
ValuePair(Proj_Wisconsin_CS83_South,	14833)
ValuePair(Proj_Wyoming_CS27_East,	14901)
ValuePair(Proj_Wyoming_CS27_East_Central,	14902)
ValuePair(Proj_Wyoming_CS27_West_Central,	14903)
ValuePair(Proj_Wyoming_CS27_West,	14904)
ValuePair(Proj_Wyoming_CS83_East,	14931)
ValuePair(Proj_Wyoming_CS83_East_Central,	14932)
ValuePair(Proj_Wyoming_CS83_West_Central,	14933)
ValuePair(Proj_Wyoming_CS83_West,	14934)
ValuePair(Proj_Alaska_CS27_1,	15001)
ValuePair(Proj_Alaska_CS27_2,	15002)
ValuePair(Proj_Alaska_CS27_3,	15003)
ValuePair(Proj_Alaska_CS27_4,	15004)
ValuePair(Proj_Alaska_CS27_5,	15005)
ValuePair(Proj_Alaska_CS27_6,	15006)
ValuePair(Proj_Alaska_CS27_7,	15007)
ValuePair(Proj_Alaska_CS27_8,	15008)
ValuePair(Proj_Alaska_CS27_9,	15009)
ValuePair(Proj_Alaska_CS27_10,	15010)
ValuePair(Proj_Alaska_CS83_1,	15031)
ValuePair(Proj_Alaska_CS83_2,	15032)
ValuePair(Proj_Alaska_CS83_3,	15033)
ValuePair(Proj_Alaska_CS83_4,	15034)
ValuePair(Proj_Alaska_CS83_5,	15035)
ValuePair(Proj_Alaska_CS83_6,	15036)
ValuePair(Proj_Alaska_CS83_7,	15037)
ValuePair(Proj_Alaska_CS83_8,	15038)
ValuePair(Proj_Alaska_CS83_9,	15039)
ValuePair(Proj_Alaska_CS83_10,	15040)
ValuePair(Proj_Hawaii_CS27_1,	15101)
ValuePair(Proj_Hawaii_CS27_2,	15102)
ValuePair(Proj_Hawaii_CS27_3,	15103)
ValuePair(Proj_Hawaii_CS27_4,	15104)
ValuePair(Proj_Hawaii_CS27_5,	15105)
ValuePair(Proj_Hawaii_CS83_1,	15131)
ValuePair(Proj_Hawaii_CS83_2,	15132)
ValuePair(Proj_Hawaii_CS83_3,	15133)
ValuePair(Proj_Hawaii_CS83_4,	15134)
ValuePair(Proj_Hawaii_CS83_5,	15135)
ValuePair(Proj_Puerto_Rico_CS27,	15201)
ValuePair(Proj_St_Croix,	15202)
ValuePair(Proj_Puerto_Rico_Virgin_Is,	15230)
ValuePair(Proj_BLM_14N_feet,	15914)
ValuePair(Proj_BLM_15N_feet,	15915)
ValuePair(Proj_BLM_16N_feet,	15916)
ValuePair(Proj_BLM_17N_feet,	15917)
ValuePair(Proj_UTM_zone_1N,  16001)
ValuePair(Proj_UTM_zone_2N,  16002)
ValuePair(Proj_UTM_zone_3N,  16003)
ValuePair(Proj_UTM_zone_4N,  16004)
ValuePair(Proj_UTM_zone_5N,  16005)
ValuePair(Proj_UTM_zone_6N,  16006)
ValuePair(Proj_UTM_zone_7N,  16007)
ValuePair(Proj_UTM_zone_8N,  16008)
ValuePair(Proj_UTM_zone_9N,  16009)
ValuePair(Proj_UTM_zone_10N, 16010)
ValuePair(Proj_UTM_zone_11N, 16011)
ValuePair(Proj_UTM_zone_12N, 16012)
ValuePair(Proj_UTM_zone_13N, 16013)
ValuePair(Proj_UTM_zone_14N, 16014)
ValuePair(Proj_UTM_zone_15N, 16015)
ValuePair(Proj_UTM_zone_16N, 16016)
ValuePair(Proj_UTM_zone_17N, 16017)
ValuePair(Proj_UTM_zone_18N, 16018)
ValuePair(Proj_UTM_zone_19N, 16019)
ValuePair(Proj_UTM_zone_20N, 16020)
ValuePair(Proj_UTM_zone_21N, 16021)
ValuePair(Proj_UTM_zone_22N, 16022)
ValuePair(Proj_UTM_zone_23N, 16023)
ValuePair(Proj_UTM_zone_24N, 16024)
ValuePair(Proj_UTM_zone_25N, 16025)
ValuePair(Proj_UTM_zone_26N, 16026)
ValuePair(Proj_UTM_zone_27N, 16027)
ValuePair(Proj_UTM_zone_28N, 16028)
ValuePair(Proj_UTM_zone_29N, 16029)
ValuePair(Proj_UTM_zone_30N, 16030)
ValuePair(Proj_UTM_zone_31N, 16031)
ValuePair(Proj_UTM_zone_32N, 16032)
ValuePair(Proj_UTM_zone_33N, 16033)
ValuePair(Proj_UTM_zone_34N, 16034)
ValuePair(Proj_UTM_zone_35N, 16035)
ValuePair(Proj_UTM_zone_36N, 16036)
ValuePair(Proj_UTM_zone_37N, 16037)
ValuePair(Proj_UTM_zone_38N, 16038)
ValuePair(Proj_UTM_zone_39N, 16039)
ValuePair(Proj_UTM_zone_40N, 16040)
ValuePair(Proj_UTM_zone_41N, 16041)
ValuePair(Proj_UTM_zone_42N, 16042)
ValuePair(Proj_UTM_zone_43N, 16043)
ValuePair(Proj_UTM_zone_44N, 16044)
ValuePair(Proj_UTM_zone_45N, 16045)
ValuePair(Proj_UTM_zone_46N, 16046)
ValuePair(Proj_UTM_zone_47N, 16047)
ValuePair(Proj_UTM_zone_48N, 16048)
ValuePair(Proj_UTM_zone_49N, 16049)
ValuePair(Proj_UTM_zone_50N, 16050)
ValuePair(Proj_UTM_zone_51N, 16051)
ValuePair(Proj_UTM_zone_52N, 16052)
ValuePair(Proj_UTM_zone_53N, 16053)
ValuePair(Proj_UTM_zone_54N, 16054)
ValuePair(Proj_UTM_zone_55N, 16055)
ValuePair(Proj_UTM_zone_56N, 16056)
ValuePair(Proj_UTM_zone_57N, 16057)
ValuePair(Proj_UTM_zone_58N, 16058)
ValuePair(Proj_UTM_zone_59N, 16059)
ValuePair(Proj_UTM_zone_60N, 16060)
ValuePair(Proj_UTM_zone_1S,  16101)
ValuePair(Proj_UTM_zone_2S,  16102)
ValuePair(Proj_UTM_zone_3S,  16103)
ValuePair(Proj_UTM_zone_4S,  16104)
ValuePair(Proj_UTM_zone_5S,  16105)
ValuePair(Proj_UTM_zone_6S,  16106)
ValuePair(Proj_UTM_zone_7S,  16107)
ValuePair(Proj_UTM_zone_8S,  16108)
ValuePair(Proj_UTM_zone_9S,  16109)
ValuePair(Proj_UTM_zone_10S, 16110)
ValuePair(Proj_UTM_zone_11S, 16111)
ValuePair(Proj_UTM_zone_12S, 16112)
ValuePair(Proj_UTM_zone_13S, 16113)
ValuePair(Proj_UTM_zone_14S, 16114)
ValuePair(Proj_UTM_zone_15S, 16115)
ValuePair(Proj_UTM_zone_16S, 16116)
ValuePair(Proj_UTM_zone_17S, 16117)
ValuePair(Proj_UTM_zone_18S, 16118)
ValuePair(Proj_UTM_zone_19S, 16119)
ValuePair(Proj_UTM_zone_20S, 16120)
ValuePair(Proj_UTM_zone_21S, 16121)
ValuePair(Proj_UTM_zone_22S, 16122)
ValuePair(Proj_UTM_zone_23S, 16123)
ValuePair(Proj_UTM_zone_24S, 16124)
ValuePair(Proj_UTM_zone_25S, 16125)
ValuePair(Proj_UTM_zone_26S, 16126)
ValuePair(Proj_UTM_zone_27S, 16127)
ValuePair(Proj_UTM_zone_28S, 16128)
ValuePair(Proj_UTM_zone_29S, 16129)
ValuePair(Proj_UTM_zone_30S, 16130)
ValuePair(Proj_UTM_zone_31S, 16131)
ValuePair(Proj_UTM_zone_32S, 16132)
ValuePair(Proj_UTM_zone_33S, 16133)
ValuePair(Proj_UTM_zone_34S, 16134)
ValuePair(Proj_UTM_zone_35S, 16135)
ValuePair(Proj_UTM_zone_36S, 16136)
ValuePair(Proj_UTM_zone_37S, 16137)
ValuePair(Proj_UTM_zone_38S, 16138)
ValuePair(Proj_UTM_zone_39S, 16139)
ValuePair(Proj_UTM_zone_40S, 16140)
ValuePair(Proj_UTM_zone_41S, 16141)
ValuePair(Proj_UTM_zone_42S, 16142)
ValuePair(Proj_UTM_zone_43S, 16143)
ValuePair(Proj_UTM_zone_44S, 16144)
ValuePair(Proj_UTM_zone_45S, 16145)
ValuePair(Proj_UTM_zone_46S, 16146)
ValuePair(Proj_UTM_zone_47S, 16147)
ValuePair(Proj_UTM_zone_48S, 16148)
ValuePair(Proj_UTM_zone_49S, 16149)
ValuePair(Proj_UTM_zone_50S, 16150)
ValuePair(Proj_UTM_zone_51S, 16151)
ValuePair(Proj_UTM_zone_52S, 16152)
ValuePair(Proj_UTM_zone_53S, 16153)
ValuePair(Proj_UTM_zone_54S, 16154)
ValuePair(Proj_UTM_zone_55S, 16155)
ValuePair(Proj_UTM_zone_56S, 16156)
ValuePair(Proj_UTM_zone_57S, 16157)
ValuePair(Proj_UTM_zone_58S, 16158)
ValuePair(Proj_UTM_zone_59S, 16159)
ValuePair(Proj_UTM_zone_60S, 16160)
ValuePair(Proj_Gauss_Kruger_zone_0, 16200)
ValuePair(Proj_Gauss_Kruger_zone_1, 16201)
ValuePair(Proj_Gauss_Kruger_zone_2, 16202)
ValuePair(Proj_Gauss_Kruger_zone_3, 16203)
ValuePair(Proj_Gauss_Kruger_zone_4, 16204)
ValuePair(Proj_Gauss_Kruger_zone_5, 16205)
ValuePair(Proj_Map_Grid_of_Australia_48,	17348)
ValuePair(Proj_Map_Grid_of_Australia_49,	17349)
ValuePair(Proj_Map_Grid_of_Australia_50,	17350)
ValuePair(Proj_Map_Grid_of_Australia_51,	17351)
ValuePair(Proj_Map_Grid_of_Australia_52,	17352)
ValuePair(Proj_Map_Grid_of_Australia_53,	17353)
ValuePair(Proj_Map_Grid_of_Australia_54,	17354)
ValuePair(Proj_Map_Grid_of_Australia_55,	17355)
ValuePair(Proj_Map_Grid_of_Australia_56,	17356)
ValuePair(Proj_Map_Grid_of_Australia_57,	17357)
ValuePair(Proj_Map_Grid_of_Australia_58,	17358)
ValuePair(Proj_Australian_Map_Grid_48,	17448)
ValuePair(Proj_Australian_Map_Grid_49,	17449)
ValuePair(Proj_Australian_Map_Grid_50,	17450)
ValuePair(Proj_Australian_Map_Grid_51,	17451)
ValuePair(Proj_Australian_Map_Grid_52,	17452)
ValuePair(Proj_Australian_Map_Grid_53,	17453)
ValuePair(Proj_Australian_Map_Grid_54,	17454)
ValuePair(Proj_Australian_Map_Grid_55,	17455)
ValuePair(Proj_Australian_Map_Grid_56,	17456)
ValuePair(Proj_Australian_Map_Grid_57,	17457)
ValuePair(Proj_Australian_Map_Grid_58,	17458)
ValuePair(Proj_Argentina_1,	18031)
ValuePair(Proj_Argentina_2,	18032)
ValuePair(Proj_Argentina_3,	18033)
ValuePair(Proj_Argentina_4,	18034)
ValuePair(Proj_Argentina_5,	18035)
ValuePair(Proj_Argentina_6,	18036)
ValuePair(Proj_Argentina_7,	18037)
ValuePair(Proj_Colombia_3W,	18051)
ValuePair(Proj_Colombia_Bogota,	18052)
ValuePair(Proj_Colombia_3E,	18053)
ValuePair(Proj_Colombia_6E,	18054)
ValuePair(Proj_Egypt_Red_Belt,	18072)
ValuePair(Proj_Egypt_Purple_Belt,	18073)
ValuePair(Proj_Extended_Purple_Belt,	18074)
ValuePair(Proj_New_Zealand_North_Island_Nat_Grid,	18141)
ValuePair(Proj_New_Zealand_South_Island_Nat_Grid,	18142)
ValuePair(Proj_Bahrain_Grid,	19900)
ValuePair(Proj_Netherlands_E_Indies_Equatorial,	19905)
ValuePair(Proj_RSO_Borneo,	19912)
/* end of list */
